# **Tank** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]


[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.6-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/项目-jtyoui.tank-black.svg)]()

## 介绍
用Python简单实现的坦克大战

### 安装
    pip install jtyoui


#### 使用说明,需要单独安装Pygame模块 pip install Pygame

```python
from jtyoui.game import TankGame

if __name__ == '__main__':
    TankGame().start_game()
```

***

[1]: https://blog.jtyoui.com


